<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="114"/>
        <source>Command:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="116"/>
        <source>Shortcuts:</source>
        <translation>Dreceres:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="127"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="128"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="205"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="211"/>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="154"/>
        <source>Add Command</source>
        <translation>Afegeix una ordre</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="160"/>
        <source>Edit Command</source>
        <translation>Edita l&apos;ordre</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="170"/>
        <source>Delete Command</source>
        <translation>Elimina l&apos;ordre</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="191"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="193"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Afegeix</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="195"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Desa</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="372"/>
        <source>Please enter a name</source>
        <translation>Si us plau, escriviu un nom.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="386"/>
        <source>Please enter a command</source>
        <translation>Si us plau, escriviu una ordre.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="436"/>
        <source>The name already exists,</source>
        <translation>El nom ja existeix;</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="437"/>
        <source>please input another one.</source>
        <translation>si us plau, escriviu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="618"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="212"/>
        <source>Add Command</source>
        <translation>Afegeix una ordre</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="216"/>
        <source>No commands yet</source>
        <translation>Encara no hi ha cap ordre.</translation>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="50"/>
        <source>Custom commands</source>
        <translation>Ordres personalitzades</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="146"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="236"/>
        <source>Custom Theme</source>
        <translation>Tema personalitzat</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="260"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="264"/>
        <source>Light</source>
        <translation>Lleugera</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="269"/>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="323"/>
        <source>Fore color:</source>
        <translation>Color frontal:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="330"/>
        <source>Back color:</source>
        <translation>Color de fons:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="348"/>
        <source>Prompt PS1:</source>
        <translation>Indicador PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="352"/>
        <source>Prompt PS2:</source>
        <translation>Indicador PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="423"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <source>Delete Server</source>
        <translation>Elimina el servidor</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="298"/>
        <location filename="../src/views/listview.cpp" line="492"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Segur que voleu eliminar %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="269"/>
        <location filename="../src/main/mainwindow.cpp" line="324"/>
        <source>New window</source>
        <translation>Finestra nova</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="339"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="755"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="757"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1829"/>
        <source>Type path to download file</source>
        <translation>Escriviu el camí per baixar el fitxer.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2135"/>
        <source>Custom Theme</source>
        <translation>Tema personalitzat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/views/listview.cpp" line="304"/>
        <location filename="../src/views/listview.cpp" line="493"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="236"/>
        <location filename="../src/common/utils.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="305"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="494"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="514"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close workspace</source>
        <translation>Tanca l&apos;espai de treball</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="517"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Close other workspaces</source>
        <translation>Tanca altres espais de treball</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1177"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>No s&apos;ha pogut trobar &quot;%1&quot;, s&apos;inicia &quot;%2&quot;. Si us plau, comproveu el perfil de l&apos;intèrpret d&apos;ordres.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1183"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>No s&apos;ha pogut obrir &quot;%1&quot;. No es pot executar.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1185"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>No s&apos;ha pogut trobar &quot;%1&quot;, no es pot executar.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1215"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>La sortida s&apos;ha suspès prement Ctrl+S. Premeu Ctrl+Q per reprendre-la.</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="132"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Tab title format</source>
        <translation>Format del títol de les pestanyes</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="134"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Remote tab title format</source>
        <translation>Format remot del títol de les pestanyes</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamedlg.cpp" line="203"/>
        <location filename="../src/views/tabbar.cpp" line="504"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Rename title</source>
        <translation>Canvia&apos;n el títol</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="498"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close tab</source>
        <translation>Tanca la pestanya</translation>
    </message>
    <message>
        <location filename="../src/views/tabbar.cpp" line="501"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Close other tabs</source>
        <translation>Tanca les altres pestanyes</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Copy on select</source>
        <translation>Copia en seleccionar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Cursor blink</source>
        <translation>Intermitència del cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Cursor style</source>
        <translation>Estil del cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Scroll on keystroke</source>
        <translation>Desplaçament en tocar una tecla</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Scroll on output</source>
        <translation>Desplaçament en una sortida</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Oculta la finestra desplegable en perdre el focus.</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <location filename="../src/main/service.cpp" line="159"/>
        <source>Blur background</source>
        <translation>Fons difuminat</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Use on starting</source>
        <translation>Usa en iniciar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Font</source>
        <translation>Lletra</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Font size</source>
        <translation>Mida de la lletra</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <location filename="../src/main/service.cpp" line="182"/>
        <source>Opacity</source>
        <translation>Opacitat</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Advanced</source>
        <translation>Avançat</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Scroll</source>
        <translation>Desplaçament</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Basic</source>
        <translation>Bàsic</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/main/mainwindow.cpp" line="1671"/>
        <source>Others</source>
        <translation>Altres</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <location filename="../src/main/terminalapplication.cpp" line="36"/>
        <location filename="../src/main/mainwindow.cpp" line="1669"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Workspace</source>
        <translation>Espai de treball</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Custom commands</source>
        <translation>Ordres personalitzades</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Remote management</source>
        <translation>Gestió remota</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <location filename="../src/main/mainwindow.cpp" line="1735"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Default size</source>
        <translation>Mida per defecte</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Select all</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Jump to next command</source>
        <translation>Salta a l&apos;ordre següent</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <source>Jump to previous command</source>
        <translation>Salta a l&apos;ordre anterior</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom in</source>
        <translation>Ampliació</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Zoom out</source>
        <translation>Reducció</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Close other windows</source>
        <translation>Tanca les altres finestres</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Close window</source>
        <translation>Tanca la finestra</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Horizontal split</source>
        <translation>Divisió horitzontal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>New tab</source>
        <translation>Pestanya nova</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Next tab</source>
        <translation>Pestanya següent</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <location filename="../src/main/mainwindow.cpp" line="1715"/>
        <source>Previous tab</source>
        <translation>Pestanya anterior</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select left workspace</source>
        <translation>Selecciona l&apos;espai de treball de l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select lower workspace</source>
        <translation>Selecciona l&apos;espai de treball de baix</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/main/mainwindow.cpp" line="1717"/>
        <source>Select right workspace</source>
        <translation>Selecciona l&apos;espai de treball de la dreta</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select upper workspace</source>
        <translation>Selecciona l&apos;espai de treball de dalt</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Vertical split</source>
        <translation>Divisió vertical</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <location filename="../src/main/mainwindow.cpp" line="1700"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Tab titles</source>
        <translation>Títols de les pestanyes</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 1</source>
        <translation>Ves a la pestanya 1</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 2</source>
        <translation>Ves a la pestanya 2</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <location filename="../src/main/mainwindow.cpp" line="1718"/>
        <source>Go to tab 3</source>
        <translation>Ves a la pestanya 3</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 4</source>
        <translation>Ves a la pestanya 4</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 5</source>
        <translation>Ves a la pestanya 5</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <location filename="../src/main/mainwindow.cpp" line="1719"/>
        <source>Go to tab 6</source>
        <translation>Ves a la pestanya 6</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 7</source>
        <translation>Ves a la pestanya 7</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 8</source>
        <translation>Ves a la pestanya 8</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <location filename="../src/main/mainwindow.cpp" line="1720"/>
        <source>Go to tab 9</source>
        <translation>Ves a la pestanya 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="155"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Inhabiliteu el control de flux amb Ctrl+S, Ctrl+Q.</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="157"/>
        <source>Shell profile</source>
        <translation>Perfil de l&apos;intèrpret</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="517"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="379"/>
        <source>The name should be no more than 32 characters</source>
        <translation>El nom no hauria de superar els 32 caràcters.</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="583"/>
        <source>Select the private key file</source>
        <translation>Selecciona el fitxer de clau privada</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="587"/>
        <location filename="../src/main/mainwindow.cpp" line="1851"/>
        <location filename="../src/common/utils.cpp" line="133"/>
        <source>Select</source>
        <translation>Selecciona</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="39"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>El Terminal és un emulador de terminal avançat amb divisió de finestres, espais de treball, gestió remota, mode Quake i altres característiques.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1667"/>
        <source>Tabs</source>
        <translation>Pestanyes</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1687"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>Canvia el focus a la icona &quot;+&quot;</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1716"/>
        <source>Select tab</source>
        <translation>Selecciona la pestanya</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1775"/>
        <location filename="../src/common/utils.cpp" line="148"/>
        <source>Select file to upload</source>
        <translation>Seleccioneu el fitxer per carregar</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1782"/>
        <location filename="../src/common/utils.cpp" line="153"/>
        <source>Upload</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1845"/>
        <location filename="../src/common/utils.cpp" line="127"/>
        <source>Select a directory to save the file</source>
        <translation>Seleccioneu un directori per desar-hi el fitxer.</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="403"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="621"/>
        <location filename="../src/common/utils.cpp" line="254"/>
        <source>please set another one.</source>
        <translation>si us plau, establiu-ne un/a altre/a.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="173"/>
        <location filename="../src/common/utils.cpp" line="207"/>
        <source>Close this terminal?</source>
        <translation>Voleu tancar aquest terminal?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="174"/>
        <location filename="../src/common/utils.cpp" line="208"/>
        <source>There is still a process running in this terminal. Closing the terminal will kill it.</source>
        <translation>Encara hi ha un procés que s&apos;executa en aquest terminal. Tancar-lo el matarà.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="178"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will kill all of them.</source>
        <translation>Encara hi ha %1 processos que s&apos;executen en aquest terminal. Tancar-lo els matarà tots.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="203"/>
        <source>Close this window?</source>
        <translation>Voleu tancar aquesta finestra?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="184"/>
        <location filename="../src/common/utils.cpp" line="204"/>
        <source>There are still processes running in this window. Closing the window will kill all of them.</source>
        <translation>Encara hi ha processos que s&apos;executen en aquesta finestra. Tancar-la els matarà tots.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Programs are still running in terminal</source>
        <translation>Encara hi ha programes executant-se al terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Segur que voleu desinstal·lar-la?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="234"/>
        <location filename="../src/common/utils.cpp" line="238"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Segur que voleu desinstal·lar aquesta aplicació?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="235"/>
        <location filename="../src/common/utils.cpp" line="239"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>Ja no podreu usar més el Terminal.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="245"/>
        <location filename="../src/common/utils.cpp" line="289"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="323"/>
        <source>Set the work directory</source>
        <translation>Establiu el directori de treball.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="326"/>
        <source>Set the window mode on starting</source>
        <translation>Establiu el mode de finestra a l&apos;inici.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="329"/>
        <source>Execute a command in the terminal</source>
        <translation>Executa una ordre al terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Run script string in the terminal</source>
        <translation>Executa la cadena de script al terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Run in quake mode</source>
        <translation>Execució en mode quake</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Mantén el terminal obert quan l&apos;odre acabi.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="201"/>
        <source>Add Server</source>
        <translation>Afegeix un servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="205"/>
        <source>No servers yet</source>
        <translation>Encara no hi ha cap servidor.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="90"/>
        <source>Remote management</source>
        <translation>Gestió remota</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="216"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Assegureu-vos que les ordres rz i sz s&apos;han instal·lat al servidor abans de fer clic dret per penjar i baixar fitxers.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="225"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="70"/>
        <source>Advanced options</source>
        <translation>Opcions avançades</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="108"/>
        <source>Add Server</source>
        <translation>Afegeix un servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Server name:</source>
        <translation>Nom de servidor:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="146"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="156"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="184"/>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="154"/>
        <source>Address:</source>
        <translation>Adreça:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="161"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="182"/>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="195"/>
        <source>Certificate:</source>
        <translation>Certificat:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Group:</source>
        <translation>Grup:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Path:</source>
        <translation>Camí:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Command:</source>
        <translation>Ordre:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Encoding:</source>
        <translation>Codificació:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="235"/>
        <source>Backspace key:</source>
        <translation>Tecla de retrocés:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="241"/>
        <source>Delete key:</source>
        <translation>Elimina la clau:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="247"/>
        <source>Delete server</source>
        <translation>Elimina el servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="261"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="262"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Afegeix</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="266"/>
        <source>Edit Server</source>
        <translation>Edita el servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="267"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Desa</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="511"/>
        <source>Please enter a server name</source>
        <translation>Si us plau, escriviu un nom de servidor.</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="524"/>
        <source>Please enter an IP address</source>
        <translation>Si us plau, escriviu una adreça IP.</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="529"/>
        <source>Please enter a port</source>
        <translation>Si us plau, escriviu un port.</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="535"/>
        <source>Please enter a username</source>
        <translation>Si us plau, escriviu un nom d&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="549"/>
        <source>The server name already exists,</source>
        <translation>El nom del servidor ja existeix;</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="550"/>
        <source>please input another one. </source>
        <translation>si us plau, escriviu-ne un altre.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="399"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Normal window</source>
        <translation>Finestra normal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Split screen</source>
        <translation>Divideix la pantalla</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="143"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="283"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="292"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>La drecera %1 no és vàlida;</translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="299"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="306"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="312"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>La drecera %1 ja s&apos;usava;</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="60"/>
        <source>Insert</source>
        <translation>Insereix</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>username: %u</source>
        <translation>nom d&apos;usuari: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>username@: %U</source>
        <translation>nom d&apos;usuari@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="95"/>
        <source>remote host: %h</source>
        <translation>amfitrió remot: %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>session number: %#</source>
        <translation>número de sessió: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="96"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="110"/>
        <source>title set by shell: %w</source>
        <translation>títol establert per l&apos;intèrpret: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>program name: %n</source>
        <translation>nom del programa: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="107"/>
        <source>current directory (short): %d</source>
        <translation>directori actual (breu): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="108"/>
        <source>current directory (long): %D</source>
        <translation>directori actual (extens): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="109"/>
        <source>local host: %h</source>
        <translation>amfitrió local: %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="483"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="486"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="495"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Open in file manager</source>
        <translation>Obre al gestor de fitxers</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="508"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Horizontal split</source>
        <translation>Divisió horitzontal</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="511"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>Vertical split</source>
        <translation>Divisió vertical</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="521"/>
        <location filename="../src/views/termwidget.cpp" line="567"/>
        <source>New tab</source>
        <translation>Pestanya nova</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="528"/>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="530"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="547"/>
        <source>Encoding</source>
        <translation>Codificació</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Custom commands</source>
        <translation>Ordres personalitzades</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="551"/>
        <source>Remote management</source>
        <translation>Gestió remota</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="555"/>
        <source>Upload file</source>
        <translation>Carrega un fitxer</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="556"/>
        <source>Download file</source>
        <translation>Baixa el fitxer</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="561"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="189"/>
        <location filename="../src/common/utils.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="191"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="224"/>
        <location filename="../src/common/utils.cpp" line="256"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
</context>
</TS>